@@ -1,5 +1,6 @@
 ## no critic (ProhibitUnusedPrivateSubroutines)
 package Text::Template::Simple::Base::Include;
+$Text::Template::Simple::Base::Include::VERSION = '0.91';
 use strict;
 use warnings;
 
@@ -18,8 +19,6 @@ use constant TYPE_MAP   => qw(
    \   REFERENCE
 );
 
-our $VERSION = '0.90';
-
 sub _include_no_monolith {
    # no monolith eh?
    my($self, $type, $file, $opt) = @_;
@@ -215,36 +214,43 @@ sub _include_error {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Text::Template::Simple::Base::Include - Base class for Text::Template::Simple
+Text::Template::Simple::Base::Include
+
+=head1 VERSION
+
+version 0.91
 
 =head1 SYNOPSIS
 
 Private module.
 
+=head1 DESCRIPTION
+
+Private module.
+
+=head1 NAME
+
+Text::Template::Simple::Base::Include - Base class for Text::Template::Simple
+
 =head1 METHODS
 
 =head2 include
 
-=head1 DESCRIPTION
-
-This document describes version C<0.90> of C<Text::Template::Simple::Base::Include>
-released on C<5 July 2016>.
-
-Private module.
-
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Gursoy <burak@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2004 - 2016 Burak Gursoy. All rights reserved.
+This software is copyright (c) 2004 by Burak Gursoy.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.24.0 or,
-at your option, any later version of Perl 5 you may have available.
 =cut
