@@ -1,12 +1,11 @@
 package Text::Template::Simple::Compiler::Safe;
+$Text::Template::Simple::Compiler::Safe::VERSION = '0.91';
 # Safe compiler. Totally experimental
 use strict;
 use warnings;
 
 use Text::Template::Simple::Dummy;
 
-our $VERSION = '0.90';
-
 sub compile {
    shift;
    return __PACKAGE__->_object->reval(shift);
@@ -38,9 +37,17 @@ sub _permit {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Text::Template::Simple::Compiler::Safe - Safe compiler
+Text::Template::Simple::Compiler::Safe
+
+=head1 VERSION
+
+version 0.91
 
 =head1 SYNOPSIS
 
@@ -48,26 +55,25 @@ Private module.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.90> of C<Text::Template::Simple::Compiler::Safe>
-released on C<5 July 2016>.
-
 Safe template compiler.
 
+=head1 NAME
+
+Text::Template::Simple::Compiler::Safe - Safe compiler
+
 =head1 METHODS
 
 =head2 compile STRING
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Gursoy <burak@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2004 - 2016 Burak Gursoy. All rights reserved.
+This software is copyright (c) 2004 by Burak Gursoy.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.24.0 or,
-at your option, any later version of Perl 5 you may have available.
 =cut
