@@ -1,9 +1,8 @@
 package Text::Template::Simple::Constants;
+$Text::Template::Simple::Constants::VERSION = '0.91';
 use strict;
 use warnings;
 
-our $VERSION = '0.90';
-
 my($FIELD_ID);
 
 use constant RESET_FIELD         => -1;
@@ -311,9 +310,17 @@ BEGIN {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Text::Template::Simple::Constants - Constants
+Text::Template::Simple::Constants
+
+=head1 VERSION
+
+version 0.91
 
 =head1 SYNOPSIS
 
@@ -321,22 +328,21 @@ Text::Template::Simple::Constants - Constants
 
 =head1 DESCRIPTION
 
-This document describes version C<0.90> of C<Text::Template::Simple::Constants>
-released on C<5 July 2016>.
-
 Constants for Text::Template::Simple.
 
+=head1 NAME
+
+Text::Template::Simple::Constants - Constants
+
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Gursoy <burak@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2004 - 2016 Burak Gursoy. All rights reserved.
+This software is copyright (c) 2004 by Burak Gursoy.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.24.0 or,
-at your option, any later version of Perl 5 you may have available.
 =cut
