@@ -1,4 +1,5 @@
 package Text::Template::Simple::Dummy;
+$Text::Template::Simple::Dummy::VERSION = '0.91';
 # Dummy Plug provided by the nice guy Mr. Ikari from NERV :p
 # All templates are compiled into this package.
 # You can define subs/methods here and then access
@@ -10,8 +11,6 @@ use warnings;
 use Text::Template::Simple::Caller;
 use Text::Template::Simple::Util qw();
 
-our $VERSION = '0.90';
-
 sub stack { # just a wrapper
    my $opt = shift || {};
    Text::Template::Simple::Util::fatal('tts.caller.stack.hash')
@@ -24,9 +23,17 @@ sub stack { # just a wrapper
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Text::Template::Simple::Dummy - Container class
+Text::Template::Simple::Dummy
+
+=head1 VERSION
+
+version 0.91
 
 =head1 SYNOPSIS
 
@@ -34,11 +41,12 @@ Text::Template::Simple::Dummy - Container class
 
 =head1 DESCRIPTION
 
-This document describes version C<0.90> of C<Text::Template::Simple::Dummy>
-released on C<5 July 2016>.
-
 All templates are compiled into this class.
 
+=head1 NAME
+
+Text::Template::Simple::Dummy - Container class
+
 =head1 FUNCTIONS
 
 C<Text::Template::Simple::Dummy> contains some utility functions
@@ -59,15 +67,13 @@ See L<Text::Template::Simple::Caller> for more information.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Gursoy <burak@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2004 - 2016 Burak Gursoy. All rights reserved.
+This software is copyright (c) 2004 by Burak Gursoy.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.24.0 or,
-at your option, any later version of Perl 5 you may have available.
 =cut
