@@ -1,4 +1,5 @@
 package Text::Template::Simple::IO;
+$Text::Template::Simple::IO::VERSION = '0.91';
 use strict;
 use warnings;
 use constant MY_IO_LAYER      => 0;
@@ -14,8 +15,6 @@ use Text::Template::Simple::Util qw(
    LOG
 );
 
-our $VERSION = '0.90';
-
 sub new {
    my $class = shift;
    my $layer = shift;
@@ -194,9 +193,17 @@ sub DESTROY {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Text::Template::Simple::IO - I/O methods
+Text::Template::Simple::IO
+
+=head1 VERSION
+
+version 0.91
 
 =head1 SYNOPSIS
 
@@ -204,11 +211,12 @@ Text::Template::Simple::IO - I/O methods
 
 =head1 DESCRIPTION
 
-This document describes version C<0.90> of C<Text::Template::Simple::IO>
-released on C<5 July 2016>.
-
    TODO
 
+=head1 NAME
+
+Text::Template::Simple::IO - I/O methods
+
 =head1 METHODS
 
 =head2 new IO_LAYER
@@ -244,15 +252,13 @@ and returns the full path to the file if it exists.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Gursoy <burak@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2004 - 2016 Burak Gursoy. All rights reserved.
+This software is copyright (c) 2004 by Burak Gursoy.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.24.0 or,
-at your option, any later version of Perl 5 you may have available.
 =cut
