@@ -1,4 +1,5 @@
 package Text::Template::Simple::Util;
+$Text::Template::Simple::Util::VERSION = '0.91';
 use strict;
 use warnings;
 use base qw( Exporter );
@@ -9,8 +10,6 @@ use Text::Template::Simple::Constants qw(
    EMPTY_STRING
 );
 
-our $VERSION = '0.90';
-
 BEGIN {
    if ( UNICODE_PERL ) {
       # older perl binmode() does not accept a second param
@@ -232,9 +231,17 @@ sub _is_parent_object {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Text::Template::Simple::Util - Utility functions
+Text::Template::Simple::Util
+
+=head1 VERSION
+
+version 0.91
 
 =head1 SYNOPSIS
 
@@ -242,11 +249,12 @@ Text::Template::Simple::Util - Utility functions
 
 =head1 DESCRIPTION
 
-This document describes version C<0.90> of C<Text::Template::Simple::Util>
-released on C<5 July 2016>.
-
 Contains utility functions for Text::Template::Simple.
 
+=head1 NAME
+
+Text::Template::Simple::Util - Utility functions
+
 =head1 FUNCTIONS
 
 =head2 DEBUG
@@ -305,15 +313,13 @@ the C<MYLOG> sub.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Gursoy <burak@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2004 - 2016 Burak Gursoy. All rights reserved.
+This software is copyright (c) 2004 by Burak Gursoy.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.24.0 or,
-at your option, any later version of Perl 5 you may have available.
 =cut
